import requests

class APIRequest:
    def __init__(self, url):
        self.url = url

    def send_request(self, method='GET', params=None, headers=None, data=None, timeout=None):
        response = requests.request(method, self.url, params=params, headers=headers, data=data, timeout=timeout)
        return response

    def get(self, params=None, headers=None, timeout=None):
        return self.send_request('GET', params=params, headers=headers, timeout=timeout)

    def post(self, data=None, headers=None, timeout=None):
        return self.send_request('POST', data=data, headers=headers, timeout=timeout)

    def put(self, data=None, headers=None, timeout=None):
        return self.send_request('PUT', data=data, headers=headers, timeout=timeout)

    def delete(self, params=None, headers=None, timeout=None):
        return self.send_request('DELETE', params=params, headers=headers, timeout=timeout)



from api_client.APIRequest import APIRequest
from api_client.APIResponse import APIResponse


class UserEndpoint:
    def __init__(self, base_url):
        self.base_url = base_url

    def get_user(self, user_id):
        url = f'{self.base_url}/users/{user_id}'
        request = APIRequest(url)
        response = request.send_request()
        return APIResponse(response)


class PostEndpoint:
    def __init__(self, base_url):
        self.base_url = base_url

    def create_post(self, data):
        url = f'{self.base_url}/posts'
        request = APIRequest(url)
        response = request.send_request(method='POST', data=data)
        return APIResponse(response)



class DataTransformer:
    def __init__(self, data):
        self.data = data

    def transform_data(self):
        # Logika transformacji danych z API
        transformed_data = ...
        return transformed_data



class APIResponse:
    def __init__(self, response):
        self.response = response

    def get_status_code(self):
        return self.response.status_code

    def get_json(self):
        return self.response.json()



from setuptools import setup, find_packages

setup(
    name='biblioteka',
    version='1.0',
    author='Michal',
    url='https://git.e-science.pl/micpuc157_dpp_2023.group/python_pip',
    packages=find_packages(),
)



import base64
class BasicAuth:
    def __init__(self, username, password):
        self.username = username
        self.password = password

    def get_auth_header(self):
        auth_header = f'Basic {base64.b64encode(f"{self.username}:{self.password}".encode()).decode()}'
        return {'Authorization': auth_header}


class TokenAuth:
    def __init__(self, token):
        self.token = token

    def get_auth_header(self):
        return {'Authorization': f'Token {self.token}'}
